# Families

Families define the distribution and link functions for GAM models. Each family corresponds to a statistical distribution and supports specific link functions.

!!! warning

    The families are not well tested, and mgcv has many families with inconsistent structures of inputs and outputs. Some families, although provided here, may not
    currently work (but will be supported in due course).

::: pymgcv.families.Gaussian
    options:
      members:
        - "__init__"
::: pymgcv.families.Binomial
    options:
      members:
        - "__init__"
::: pymgcv.families.Gamma
    options:
      members:
        - "__init__"
::: pymgcv.families.InverseGaussian
    options:
      members:
        - "__init__"
::: pymgcv.families.Poisson
    options:
      members:
        - "__init__"
::: pymgcv.families.Quasi
    options:
      members:
        - "__init__"
::: pymgcv.families.QuasiBinomial
    options:
      members:
        - "__init__"
::: pymgcv.families.QuasiPoisson
    options:
      members:
        - "__init__"
::: pymgcv.families.Tweedie
    options:
      members:
        - "__init__"
::: pymgcv.families.NegBin
    optionsTweedie:
      members:
        - "__init__"
::: pymgcv.families.Betar
    options:
      members:
        - "__init__"
::: pymgcv.families.CNorm
    options:
      members:
        - "__init__"
::: pymgcv.families.CLog
    options:
      members:
        - "__init__"
::: pymgcv.families.CPois
    options:
      members:
        - "__init__"
::: pymgcv.families.OCat
    options:
      members:
        - "__init__"
::: pymgcv.families.Scat
    options:
      members:
        - "__init__"
::: pymgcv.families.Tw
    options:
      members:
        - "__init__"
::: pymgcv.families.ZIP
    options:
      members:
        - "__init__"
::: pymgcv.families.CoxPH
    options:
      members:
        - "__init__"
::: pymgcv.families.GammaLS
    Options:
      members:
        - "__init__"
::: pymgcv.families.GauLSS
    options:
      members:
        - "__init__"
::: pymgcv.families.GevLSS
    Options:
      members:
        - "__init__"
::: pymgcv.families.GumbLS
    Options:
      members:
        - "__init__"
::: pymgcv.families.Multinom
    options:
      members:
        - "__init__"
::: pymgcv.families.MVN
    options:
      members:
        - "__init__"
::: pymgcv.families.Shash
    options:
      members:
        - "__init__"
::: pymgcv.families.TwLSS
    Options:
      members:
        - "__init__"
::: pymgcv.families.ZipLSS
    Options:
      members:
        - "__init__"

::: pymgcv.families.AbstractFamily
::: pymgcv.families.SupportsCDF
